@@ -21,7 +21,7 @@ NP_NAT = pd.NaT.value
 
 # Use Date type where input does not need to represent an actual session
 # and will be parsed by parse_date.
-Date = pd.Timestamp | str | int | float | datetime.datetime
+Date = pd.Timestamp | str | int | float | datetime.datetime | datetime.date
 
 # Use Session type where input should represent an actual session and will
 # be parsed by parse_session.
@@ -575,7 +575,7 @@ class _TradingIndex:
 
         # evaluate number of indices for each session
         num_intervals = (end_nanos - start_nanos) / self.interval_nanos
-        num_indices = np.ceil(num_intervals).astype("int64")
+        num_indices = np.ceil(num_intervals).astype(np.intp)
 
         if force_close:
             if self.closed_right:
