@@ -38,5 +38,13 @@ class TestXBOMCalendar(ExchangeCalendarTestBase):
             "2017-10-02",
             "2017-10-20",
             "2017-12-25",
+            "2024-01-22",
             "2025-05-01",
         ]
+
+    @pytest.fixture
+    def non_holidays_sample(self):
+        yield [
+            # Special trading session on Saturday, January 20, 2024.
+            "2024-01-20",
+        ]
